
source("http://bioconductor.org/biocLite.R")
biocLite("DESeq2")


# Differntial gene experssion analysis using DESeq2

input.dir <- "/home/kokonech/work/rna_seq_seminar/Glcn_study/counts"

sampleFiles <- grep("counts", list.files(input.dir), value=T)

sampleConditions <- c("Glcn_neg","Glcn_neg","Glcn_neg", "Glcn_pos", "Glcn_pos", "Glcn_pos")

sampleNames <- sub(".counts.txt", "", sampleFiles)


sampleTable <- data.frame(sampleName = sampleFiles, file = sampleFiles, condition = sampleConditions)

# Create special object
library(DESeq2)
dds <- DESeqDataSetFromHTSeqCount(sampleTable = sampleTable, directory= input.dir, design= ~ condition)

dds

# Counts
head(counts(dds))

# This are the condition
dds$condition

# Normalization
dds <- estimateSizeFactors(dds)
sizeFactors(dds)
# Some EDA

logcounts <- log2( counts(dds, normalized=TRUE) + 1)

# Counts density

num_samples <- ncol(logcounts)

for (i in 1:num_samples) {
    idx <- logcounts[,i] > 1
    if (i == 1) {
        plot(density((logcounts[idx,i])), type='l', col = i, lwd=2, main="Counts density", xlab="Log2(Counts)", ylab="Density")    
    } else {
        lines(density((logcounts[idx,i])), type='l', col = i, lwd=2)
    }
}

legend("right", title="Samples", fill=1:num_samples, legend=colnames(logcounts))

# PCA

pc <- prcomp( t(logcounts))

plot(pc$x[,1], pc$x[,2], col=colData(dds)$condition)

# Clustering

plot(hclust(dist(t(logcounts))), labels=colData(dds)$condition)


# Run deseq

dds <- DESeq(dds)

res <- results(dds)
plotMA(dds, ylim=c(-4,4))

resSort <- res[order(res$padj),]

resOut <- subset(resSort, resSort$padj < 0.05 )

# get annotations

library("org.Ce.eg.db")

geneinfo <- select(org.Ce.eg.db, 
                   keys=rownames(resSort)[1:20], 
                   columns=c("ENSEMBL", "SYMBOL", "GENENAME"), keytype="ENSEMBL")

geneinfo

# cute reporting

library(ReportingTools)


deReport <- HTMLReport(shortName = "RNAseq_analysis", title = "RNA-seq with DESEq: Glcn study", 
                       reportDirectory = "./reports")

publish(ddsHTSeq,deReport, pvalueCutoff=0.05, annotation.db = org.Ce.eg.db, factor = colData(ddsHTSeq)$condition)
finish(deReport)
